/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.common.command;

import java.time.ZonedDateTime;
import java.util.Collections;
import java.util.Map;

import de.ozgcloud.apilib.user.OzgCloudUserId;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import de.ozgcloud.common.datatype.StringBasedValue;
import lombok.Builder;
import lombok.Getter;

@Builder
@Getter
public class OzgCloudCommand {

	private OzgCloudCommandId id;

	private OzgCloudVorgangId vorgangId;
	/**
	 * Id of the entity, that is referenced by this command to be processed. That
	 * can be any Id, for example vorgangId, fileId and so on.
	 */
	private StringBasedValue relationId;
	/**
	 * Version of the entity, to be processed by this command. Used for optimistic
	 * locking.
	 */
	private Long relationVersion;

	private String order;

	private ZonedDateTime createdAt;
	private ZonedDateTime finishedAt;

	private OzgCloudUserId createdBy;
	private OzgCloudCommandStatus status;

	@Builder.Default
	private Map<String, Object> bodyObject = Collections.emptyMap();
	/**
	 * @deprecated use {@link OzgCloudCommand#bodyObject}
	 */
	@Deprecated(since = "0.2.0", forRemoval = true)
	private Map<String, String> body;

	private String errorMessage;

	private String createdResource;
}
