/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.apilib.client_attribute;

import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcAccessPermission;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttribute;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttributeValue;

public class GrpcClientAttributeTestFactory {

	public static final GrpcAccessPermission ACCESS_PERMISSION = GrpcAccessPermission.READ_ONLY;

	public static final GrpcClientAttributeValue BOOLEAN_VALUE =
		GrpcClientAttributeValue.newBuilder().setBoolValue(OzgCloudClientAttributeTestFactory.BOOLEAN_VALUE).build();

	public static final GrpcClientAttributeValue STRING_VALUE =
		GrpcClientAttributeValue.newBuilder().setStringValue(OzgCloudClientAttributeTestFactory.STRING_VALUE).build();

	public static final GrpcClientAttributeValue LONG_VALUE = GrpcClientAttributeValue.newBuilder().setIntValue(
		OzgCloudClientAttributeTestFactory.LONG_VALUE).build();

	public static final GrpcClientAttributeValue DOUBLE_VALUE =
		GrpcClientAttributeValue.newBuilder().setDoubleValue(OzgCloudClientAttributeTestFactory.DOUBLE_VALUE).build();

	public static GrpcClientAttribute createBoolean() {
		return createBuilder().setValue(BOOLEAN_VALUE).build();
	}

	public static GrpcClientAttribute createString() {
		return createBuilder().setValue(STRING_VALUE).build();
	}

	public static GrpcClientAttribute createLong() {
		return createBuilder().setValue(LONG_VALUE).build();
	}

	public static GrpcClientAttribute createDouble() {
		return createBuilder().setValue(DOUBLE_VALUE).build();
	}

	public static GrpcClientAttribute.Builder createBuilder() {
		return GrpcClientAttribute.newBuilder()
			.setClientName(OzgCloudClientAttributeTestFactory.CLIENT)
			.setAttributeName(OzgCloudClientAttributeTestFactory.ATTRIBUTE_NAME)
			.setAccess(ACCESS_PERMISSION);
	}
}
